==> snortsms-0.14.9.tbz: www/snortsms/events/qry_sigcat.php <==
<?php
$sig_id = $_REQUEST['sig_id'];


if($_SESSION['st'] != "" )
	{
	$sql_scope .= " AND e.timestamp >= '".$_SESSION['st']."'";
	}

if($_SESSION['et'] != "" )
	{
	$sql_scope .= " AND e.timestamp <= '".$_SESSION['et']."'";
	}

$sql = "SELECT e.sid, e.cid, e.timestamp, e.viewed, s.sig_name, s.sig_sid".
	" FROM event as e".
	" LEFT JOIN signature as s ON e.signature = s.sig_id".
	" WHERE e.signature = " . $sig_id." ".
	$sql_scope.
	"AND e.signature = " . $sig_id.
	" ORDER BY timestamp DESC";




//print $sql;


$rsSigs = $db_sa->query($sql); if (DB::isError($rsSigs)) { die ($rsSigs->getDebugInfo());}


$totalrows = $rsSigs->numRows();

/*** Get Start and End rows ***/
$startrow = $_REQUEST['sr'];
if ($startrow <= 0)
	{ $startrow = 0; }
$endrow = $startrow + $GBL['maxrows'] - 1;
if ($endrow > $totalrows)
	{ $endrow = $totalrows-1; }


/*** Get pages ***/
$totalpages = round($totalrows / $GBL['maxrows'] + .5);
$curpage = $startrow / $GBL['maxrows'];

$startpage = $curpage - round($GBL['maxpages']/2);
if ($startpage <= 0)
	{ $startpage = 0; }

$endpage = $curpage + round($GBL['maxpages']/2);
if ($endpage >= $totalpages)
	{ $endpage = $totalpages; }


$sig = array();

/* Create sig summary array  */
for($rownum = $startrow ; $rownum <= $endrow ; $rownum++)
	{
	if($row = $rsSigs->fetchRow(DB_FETCHMODE_ASSOC,$rownum))
		{
	
		
		$hash = $row['cid'] ."-" . $row['sid'];
		
		$sig[$hash]['sid'] = $row['sid'];
		$sig[$hash]['cid'] = $row['cid'];
		$sig[$hash]['name'] = $row['sig_name'];
		$sig[$hash]['timestamp'] = $row['timestamp'];
		$sig[$hash]['viewed'] = $row['viewed'];
	
	
		/* Get IP Header */
		$sql = "select * FROM iphdr WHERE cid = " . $sig[$hash]['cid'] . " AND sid = " . $sig[$hash]['sid'];
		$rs_iphdr = $db_sa->query($sql); if (DB::isError($rs_iphdr)) { die ($rs_iphdr->getDebugInfo());}
		$iphdr = $rs_iphdr->fetchRow(DB_FETCHMODE_ASSOC);
		$sig[$hash]['ip_proto'] = $iphdr['ip_proto'];	
		$sig[$hash]['ip_src'] = long2ip($iphdr['ip_src']);
		$sig[$hash]['ip_dst'] = long2ip($iphdr['ip_dst']);
		$rs_iphdr->free();
	
		
		if(  $iphdr['ip_proto'] == 6 )
			{
			/* Get TCP Header */
			$sql = "select * FROM tcphdr WHERE cid = " . $sig[$hash]['cid'] . " AND sid = " . $sig[$hash]['sid'];
			$rs_tcphdr = $db_sa->query($sql); if (DB::isError($rs_tcphdr)) { die ($rs_tcphdr->getDebugInfo());}
			$tcphdr = $rs_tcphdr->fetchRow(DB_FETCHMODE_ASSOC);
			$sig[$hash]['port_dst'] = $tcphdr['tcp_dport'];
			$sig[$hash]['port_src'] = $tcphdr['tcp_sport'];
			$rs_tcphdr->free();		
	
			}
		elseif(  $row['ip_proto'] == 17 )
			{
			/* Get UDP Header */
			$sql = "select * FROM udphdr WHERE cid = " . $sig[$hash]['cid'] . " AND sid = " . $sig[$hash]['sid'];
			$rs_udphdr = $db_sa->query($sql); if (DB::isError($rs_udphdr)) { die ($rs_udphdr->getDebugInfo());}
			$udphdr = $rs_udphdr->fetchRow(DB_FETCHMODE_ASSOC);
			$sig[$hash]['port_dst'] = $udphdr['tcp_dport'];
			$sig[$hash]['port_src'] = $udphdr['tcp_sport'];
			$rs_udphdr->free();
			}
		
		}
		
	}

	
?>
<script language="JavaScript" type="text/javascript">
<!-- 
function CheckAllINBOX()
	{
	for (var i = 0; i < document.CheckForm.elements.length; i++)
		{
		if(document.CheckForm.elements[i].type == 'checkbox')
			{
			document.CheckForm.elements[i].checked = !(document.CheckForm.elements[i].checked);
			}
		}
	}
//-->
</script>

<form name="CheckForm" action="index.php" method="POST">
<input type="hidden" name="fuseaction" value="events.action">
<?
include("dsp_pagenate.php");
?>
<CENTER>
<table border="0" class="bg1"  cellpadding="0">
<tr>
<th class="combo1">Events</th>
<td  class="bg2" align="center"><b>Scope:</b> <?=$_SESSION['st']?> -&gt; <?=$_SESSION['et']?></td>
</tr>
<tr>
<td  class="bg7" colspan="2">





<table border="0" cellspacing="0" cellpadding="2" width="100%">
<tr class="bg3">
<TH>&nbsp;</TH>
<TH>Date/Time</TH>
<TH>Event Name</TH>
<TH>Source IP</TH>
<TH>Source Port</TH>
<TH>Dest IP</TH>
<TH>Dest Port</TH>
</tr>
<?
foreach ($sig as $key => $row)
	{
	$viewed = ( $row['viewed'] == 1 ? "" : "bold"   );
	$class = ( $class == "bg4" ? "bg7"  :  "bg4" );
	?>
	<tr class="<?=$class?>">
	<td><input type="checkbox" name="FRM_event[]" value="<?=$row['sid']?>-<?=$row['cid']?>"></td>
	<td nowrap><?=$row['timestamp']?></td>
	<td nowrap class="<?=$viewed?>"><a href="index.php?fuseaction=events.sigzoom&cid=<?=$row['cid']?>&sid=<?=$row['sid']?>"><?=$row['name']?></a></td>
	<td><?=$row['ip_src']?>&nbsp;</td>
	<td align="center"><?=$row['port_src']?>&nbsp;</td>
	<td><?=$row['ip_dst']?>&nbsp;</td>
	<td align="center"><?=$row['port_dst']?>&nbsp;</td>
	</tr>
	
	<?
	}
	
	
?>
<tr  class="bg2">
<td colspan="7">
<a href="javascript:void(0)" onClick="CheckAllINBOX();">[Toggle All]</a>&nbsp;
<input type="submit" value="Unread" name="action">&nbsp;
<input type="submit" value="Read" name="action">&nbsp;
<input type="submit" value="Purge" name="action">&nbsp;
</td>
</tr>

</TABLE>




</td>
</tr>
</table>
</CENTER>
</form>
<?
include("dsp_pagenate.php");
?>

==> snortsms-1.0.0.tbz: www/snortsms/events/qry_sigcat.php <==
<?php
$sig_id = $_REQUEST['sig_id'];


if($_SESSION['st'] != "" )
	{
	$sql_scope .= " AND e.timestamp >= '".$_SESSION['st']."'";
	}

if($_SESSION['et'] != "" )
	{
	$sql_scope .= " AND e.timestamp <= '".$_SESSION['et']."'";
	}

$sql = "SELECT e.sid, e.cid, e.timestamp, e.viewed, s.sig_name, s.sig_sid".
	" FROM event as e".
	" LEFT JOIN signature as s ON e.signature = s.sig_id".
	" WHERE e.signature = " . $sig_id." ".
	$sql_scope.
	"AND e.signature = " . $sig_id.
	" ORDER BY timestamp DESC";




//print $sql;


$rsSigs = $db_sa->query($sql); if (DB::isError($rsSigs)) { die ($rsSigs->getDebugInfo());}


$totalrows = $rsSigs->numRows();

/*** Get Start and End rows ***/
$startrow = $_REQUEST['sr'];
if ($startrow <= 0)
	{ $startrow = 0; }
$endrow = $startrow + $GBL['maxrows'] - 1;
if ($endrow > $totalrows)
	{ $endrow = $totalrows-1; }


/*** Get pages ***/
$totalpages = round($totalrows / $GBL['maxrows'] + .5);
$curpage = $startrow / $GBL['maxrows'];

$startpage = $curpage - round($GBL['maxpages']/2);
if ($startpage <= 0)
	{ $startpage = 0; }

$endpage = $curpage + round($GBL['maxpages']/2);
if ($endpage >= $totalpages)
	{ $endpage = $totalpages; }


$sig = array();

/* Create sig summary array  */
for($rownum = $startrow ; $rownum <= $endrow ; $rownum++)
	{
	if($row = $rsSigs->fetchRow(DB_FETCHMODE_ASSOC,$rownum))
		{
	
		
		$hash = $row['cid'] ."-" . $row['sid'];
		
		$sig[$hash]['sid'] = $row['sid'];
		$sig[$hash]['cid'] = $row['cid'];
		$sig[$hash]['name'] = $row['sig_name'];
		$sig[$hash]['timestamp'] = $row['timestamp'];
		$sig[$hash]['viewed'] = $row['viewed'];
	
	
		/* Get IP Header */
		$sql = "select * FROM iphdr WHERE cid = " . $sig[$hash]['cid'] . " AND sid = " . $sig[$hash]['sid'];
		$rs_iphdr = $db_sa->query($sql); if (DB::isError($rs_iphdr)) { die ($rs_iphdr->getDebugInfo());}
		$iphdr = $rs_iphdr->fetchRow(DB_FETCHMODE_ASSOC);
		$sig[$hash]['ip_proto'] = $iphdr['ip_proto'];	
		$sig[$hash]['ip_src'] = long2ip($iphdr['ip_src']);
		$sig[$hash]['ip_dst'] = long2ip($iphdr['ip_dst']);
		$rs_iphdr->free();
	
		
		if(  $iphdr['ip_proto'] == 6 )
			{
			/* Get TCP Header */
			$sql = "select * FROM tcphdr WHERE cid = " . $sig[$hash]['cid'] . " AND sid = " . $sig[$hash]['sid'];
			$rs_tcphdr = $db_sa->query($sql); if (DB::isError($rs_tcphdr)) { die ($rs_tcphdr->getDebugInfo());}
			$tcphdr = $rs_tcphdr->fetchRow(DB_FETCHMODE_ASSOC);
			$sig[$hash]['port_dst'] = $tcphdr['tcp_dport'];
			$sig[$hash]['port_src'] = $tcphdr['tcp_sport'];
			$rs_tcphdr->free();		
	
			}
		elseif(  $row['ip_proto'] == 17 )
			{
			/* Get UDP Header */
			$sql = "select * FROM udphdr WHERE cid = " . $sig[$hash]['cid'] . " AND sid = " . $sig[$hash]['sid'];
			$rs_udphdr = $db_sa->query($sql); if (DB::isError($rs_udphdr)) { die ($rs_udphdr->getDebugInfo());}
			$udphdr = $rs_udphdr->fetchRow(DB_FETCHMODE_ASSOC);
			$sig[$hash]['port_dst'] = $udphdr['tcp_dport'];
			$sig[$hash]['port_src'] = $udphdr['tcp_sport'];
			$rs_udphdr->free();
			}
		
		}
		
	}

	
?>
<script language="JavaScript" type="text/javascript">
<!-- 
function CheckAllINBOX()
	{
	for (var i = 0; i < document.CheckForm.elements.length; i++)
		{
		if(document.CheckForm.elements[i].type == 'checkbox')
			{
			document.CheckForm.elements[i].checked = !(document.CheckForm.elements[i].checked);
			}
		}
	}
//-->
</script>

<form name="CheckForm" action="index.php" method="POST">
<input type="hidden" name="fuseaction" value="events.action">
<?
include("dsp_pagenate.php");
?>
<CENTER>
<table border="0" class="bg1"  cellpadding="0">
<tr>
<th class="combo1">Events</th>
<td  class="bg2" align="center"><b>Window:</b> <?=$_SESSION['st']?> -&gt; <?=$_SESSION['et']?></td>
</tr>
<tr>
<td  class="bg7" colspan="2">





<table border="0" cellspacing="0" cellpadding="2" width="100%">
<tr class="bg3">
<TH>&nbsp;</TH>
<TH>Date/Time</TH>
<TH>Event Name</TH>
<TH>Source IP</TH>
<TH>Source Port</TH>
<TH>Dest IP</TH>
<TH>Dest Port</TH>
</tr>
<?
foreach ($sig as $key => $row)
	{
	$viewed = ( $row['viewed'] == 1 ? "" : "bold"   );
	$class = ( $class == "bg4" ? "bg7"  :  "bg4" );
	?>
	<tr class="<?=$class?>">
	<td><input type="checkbox" name="FRM_event[]" value="<?=$row['sid']?>-<?=$row['cid']?>"></td>
	<td nowrap><?=$row['timestamp']?></td>
	<td nowrap class="<?=$viewed?>"><a href="index.php?fuseaction=events.sigzoom&cid=<?=$row['cid']?>&sid=<?=$row['sid']?>"><?=$row['name']?></a></td>
	<td><?=$row['ip_src']?>&nbsp;</td>
	<td align="center"><?=$row['port_src']?>&nbsp;</td>
	<td><?=$row['ip_dst']?>&nbsp;</td>
	<td align="center"><?=$row['port_dst']?>&nbsp;</td>
	</tr>
	
	<?
	}
	
	
?>
<tr  class="bg2">
<td colspan="7">
<img src="images/arrow_1.png" border="0" width="24" height="20">
<SELECT name="action" onchange="this.form.submit();">
<OPTION value="">-- action --</OPTION>
<OPTION value="unread">Unread</OPTION>
<OPTION value="read">Read</OPTION>
<OPTION value=""></OPTION>
<OPTION value="purge">Purge</OPTION>
</SELECT>
<a href="javascript:void(0)" onClick="CheckAllINBOX();">[Toggle All]</a>&nbsp;

</td>
</tr>

</TABLE>




</td>
</tr>
</table>
</CENTER>
</form>
<?
include("dsp_pagenate.php");
?>
